# generated by ./ubuntubuild.sh
from distutils.core import setup

setup(
    name='pynacolada',
    version='0.2.8',
    author='H. Wouters',
    author_email='hendrikwout@gmail.com',
    packages=['pynacolada'],
    url='http://www.nowebsite.com',
    license='LICENSE.txt',
    description='easy and customized Processing huge amounts of gridded Climate Data.',
    long_description=open('README.md').read(),
)

